How to use
===========


Install with
-------------
  pip install django-simple-jsonfield


Use with
--------
  from jsonfield import JSONfield
  JSONField(whatever="Foo")

  has extra keyword database: specify which database to use, defaults to "default"
